@@ -20,7 +20,7 @@ setClass("Chain",
          prototype = prototype(elementType = "ChainBlock"),
          contains = "SimpleList")
 
-setClass("ChainFile", contains = "RTLFile")
+setClass("ChainFile", contains = "BiocFile")
 
 ChainFile <- function(path) {
   if (!isSingleString(path))
@@ -86,7 +86,7 @@ flipStrandTricky <- function(strand, flip) {
 
 smoothGaps <- function(qhits, ranges, offsets) {
     congruent_gaps <- width(gaps(ranges)) == abs(offsets)
-    congruent_gaps_rle <- Rle(congruent)
+    congruent_gaps_rle <- Rle(congruent_gaps)
     congruent_rle <- c(Rle(FALSE), congruent_gaps_rle)
     group_rle <- Rle(cumsum(!congruent_rle))
     group_ranges <- disjoin(ranges(Rle(qhits)), ranges(group_rle))
@@ -143,6 +143,12 @@ setMethod("liftOver", c("GRangesList", "Chain"),
               IRanges:::regroupBySupergroup(lifted, PartitioningByEnd(x))
           })
 
+setMethod("liftOver", c("Pairs", "Chain"),
+          function(x, chain) {
+              Pairs(liftOver(first(x), chain),
+                    liftOver(second(x), chain))
+          })
+
 setMethod("liftOver", c("ANY", "ANY"),
           function(x, chain) {
     chain <- as(chain, "Chain")
