@@ -7,9 +7,9 @@
 {
     if (isSingleString(filepath))
         return(XVector:::open_input_files(filepath)[[1L]])
-    if (!is(filepath, "connection"))
+    if (!inherits(filepath, "connection"))
         stop(wmsg("'filepath' must be a single string or a connection"))
-    if (!isSeekable(filepath))
+    if (!base::isSeekable(filepath))
         stop(wmsg("connection is not seekable"))
     filepath
 }
@@ -22,15 +22,15 @@
 readGFFPragmas <- function(filepath)
 {
     filexp <- .make_filexp_from_filepath(filepath)
-    if (is(filexp, "connection")) {
-        if (!isOpen(filexp)) {
-            open(filexp)
-            on.exit(close(filexp))
+    if (inherits(filexp, "connection")) {
+        if (!base::isOpen(filexp)) {
+            base::open(filexp)
+            on.exit(base::close(filexp))
         }
-        if (seek(filexp) != 0) {
+        if (base::seek(filexp) != 0) {
             warning(wmsg("connection is not positioned at the start ",
                          "of the file, rewinding it"), immediate.=TRUE)
-            seek(filexp, where=0)
+            base::seek(filexp, where=0)
         }
     }
     .Call(read_gff_pragmas, filexp)
@@ -266,15 +266,15 @@ readGFF <- function(filepath, version=0, columns=NULL, tags=NULL,
 {
     ## Check 'filepath'.
     filexp <- .make_filexp_from_filepath(filepath)
-    if (is(filexp, "connection")) {
-        if (!isOpen(filexp)) {
-            open(filexp)
-            on.exit(close(filexp))
+    if (inherits(filexp, "connection")) {
+        if (!base::isOpen(filexp)) {
+            base::open(filexp)
+            on.exit(base::close(filexp))
         }
-        if (seek(filexp) != 0) {
+        if (base::seek(filexp) != 0) {
             warning(wmsg("connection is not positioned at the start ",
                          "of the file, rewinding it"), immediate.=TRUE)
-            seek(filexp, where=0)
+            base::seek(filexp, where=0)
         }
     }
 
@@ -285,8 +285,8 @@ readGFF <- function(filepath, version=0, columns=NULL, tags=NULL,
     pragmas <- .Call(read_gff_pragmas, filexp)
 
     ## Rewind file.
-    if (is(filexp, "connection")) {
-        seek(filexp, where=0)
+    if (inherits(filexp, "connection")) {
+        base::seek(filexp, where=0)
     } else {
         XVector:::rewind_filexp(filexp)
     }
@@ -322,8 +322,8 @@ readGFF <- function(filepath, version=0, columns=NULL, tags=NULL,
     nrows <- scan_ans[[2L]]
 
     ## Rewind file.
-    if (is(filexp, "connection")) {
-        seek(filexp, where=0)
+    if (inherits(filexp, "connection")) {
+        base::seek(filexp, where=0)
     } else {
         XVector:::rewind_filexp(filexp)
     }
@@ -396,7 +396,7 @@ readGFF <- function(filepath, version=0, columns=NULL, tags=NULL,
 .parseSequenceRegionsAsSeqinfo <- function(lines) {
     sr <- grep("##sequence-region", lines, value=TRUE)
     srcon <- file()
-    on.exit(close(srcon))
+    on.exit(base::close(srcon))
     writeLines(sr, srcon)
     srt <- read.table(srcon, comment.char="",
                       colClasses=list(NULL, "character", "integer",
@@ -433,8 +433,9 @@ readGFFAsGRanges <- function(filepath, version=0, colnames=NULL, filter=NULL,
                              sequenceRegionsAsSeqinfo=FALSE,
                              speciesAsMetadata=FALSE)
 {
-    if (!isSingleStringOrNA(genome) && !is(genome, "Seqinfo"))
-        stop(wmsg("'genome' must be a single string or NA, or a Seqinfo"))
+    if (!(isSingleStringOrNA(genome) || is(genome, "Seqinfo")))
+        stop(wmsg("'genome' must be a single string or NA, ",
+                  "or a Seqinfo object"))
     if (!isTRUEorFALSE(sequenceRegionsAsSeqinfo))
         stop(wmsg("'sequenceRegionsAsSeqinfo' must be TRUE or FALSE"))
     if (!isTRUEorFALSE(speciesAsMetadata))
@@ -456,18 +457,50 @@ readGFFAsGRanges <- function(filepath, version=0, colnames=NULL, filter=NULL,
                       columns=columns, tags=tags, filter=filter)
     }
 
-    ## Get 'ans_seqinfo' from pragmas.
+    ## Turn data frame into GRanges.
+    ## TODO: Maybe we should be able to pass the metadata to
+    ## makeGRangesFromDataFrame()?
+    if (is.null(colnames)) {
+        ans <- makeGRangesFromDataFrame(df, keep.extra.columns=TRUE,
+                                            seqnames.field="seqid")
+    } else {
+        ans <- makeGRangesFromDataFrame(df, seqnames.field="seqid")
+        mcols(ans) <- df[ , colnames, drop=FALSE]
+    }
+
+    ## Set seqinfo.
+    ans_seqinfo <- NULL
     pragmas <- attr(df, "pragmas")
     attrcol_fmt <- attr(df, "attrcol_fmt")
     if (sequenceRegionsAsSeqinfo && attrcol_fmt == 3L) {
+        ## Get 'ans_seqinfo' from pragmas.
         ans_seqinfo <- .parseSequenceRegionsAsSeqinfo(pragmas)
-    } else if (is.na(genome)) {
-        ans_seqinfo <- NULL
     } else if (is(genome, "Seqinfo")) {
         ans_seqinfo <- genome
-    } else {
-        ans_seqinfo <- seqinfoForGenome(genome)
+        if (!all(seqlevels(ans) %in% seqlevels(ans_seqinfo)))
+            stop(wmsg("the sequence names in the GTF or GFF file are in ",
+                      "disagreement with the Seqinfo object specified via ",
+                      "the 'genome' argument"))
+    } else if (isSingleString(genome)) {
+        ans_seqinfo <- seqinfoForGenome(genome)  # can return NULL
+        if (!is.null(ans_seqinfo) &&
+            !all(seqlevels(ans) %in% seqlevels(ans_seqinfo)))
+        {
+            warning(wmsg("cannot set the seqlengths or circularity flags on ",
+                         "the GRanges object to return because the sequence ",
+                         "names in the GTF or GFF file are in disagreement ",
+                         "with the sequence names implied by the genome ",
+                         "assembly (", genome, ") specified via the 'genome' ",
+                         "argument"))
+            ans_seqinfo <- NULL
+        }
     }
+    if (!is.null(ans_seqinfo)) {
+        seqlevels(ans) <- seqlevels(ans_seqinfo)
+        seqinfo(ans) <- ans_seqinfo
+    }
+    if (isSingleString(genome))
+        genome(ans) <- genome
 
     ## Get 'ans_metadata' from pragmas.
     if (speciesAsMetadata) {
@@ -476,20 +509,6 @@ readGFFAsGRanges <- function(filepath, version=0, colnames=NULL, filter=NULL,
         ans_metadata <- list()
     }
 
-    ## Turn data frame into GRanges.
-    ## TODO: Maybe we should be able to pass the metadata to
-    ## makeGRangesFromDataFrame()?
-    if (is.null(colnames)) {
-        ans <- makeGRangesFromDataFrame(df, keep.extra.columns=TRUE,
-                                            seqinfo=ans_seqinfo,
-                                            seqnames.field="seqid")
-    } else {
-        ans <- makeGRangesFromDataFrame(df, seqinfo=ans_seqinfo,
-                                            seqnames.field="seqid")
-        mcols(ans) <- df[ , colnames, drop=FALSE]
-    }
-    genome(ans) <- genome
     metadata(ans) <- ans_metadata
     ans
 }
-
