@@ -37,14 +37,6 @@ const struct bwgVariableStepItem *b = *((struct bwgVariableStepItem **)vb);
 return (int)a->start - (int)b->start;
 }
 
-void bwgDumpSummary(struct bbiSummary *sum, FILE *f)
-/* Write out summary info to file. */
-{
-fprintf(f, "summary %d:%d-%d min=%f, max=%f, sum=%f, sumSquares=%f, validCount=%d, mean=%f\n",
-     sum->chromId, sum->start, sum->end, sum->minVal, sum->maxVal, sum->sumData,
-     sum->sumSquares, sum->validCount, sum->sumData/sum->validCount);
-}
-
 static int bwgSectionWrite(struct bwgSection *section, boolean doCompress, FILE *f)
 /* Write out section to file, filling in section->fileOffset. */
 {
@@ -1220,19 +1212,3 @@ if (sectionList == NULL)
 bwgCreate(sectionList, chromSizeHash, blockSize, itemsPerSlot, compress, keepAllChromosomes, fixedSummaries, outName);
 lmCleanup(&lm);
 }
-
-void bigWigFileCreate(
-	char *inName, 		/* Input file in ascii wiggle format. */
-	char *chromSizes, 	/* Two column tab-separated file: <chromosome> <size>. */
-	int blockSize,		/* Number of items to bundle in r-tree.  1024 is good. */
-	int itemsPerSlot,	/* Number of items in lowest level of tree.  512 is good. */
-	boolean clipDontDie,	/* If TRUE then clip items off end of chrom rather than dying. */
-	boolean compress,	/* If TRUE then compress data. */
-	char *outName)
-/* Convert ascii format wig file (in fixedStep, variableStep or bedGraph format) 
- * to binary big wig format. */
-{
-bigWigFileCreateEx( inName, chromSizes, blockSize, itemsPerSlot, clipDontDie,
-	compress, FALSE, FALSE, outName);
-}
-
