@@ -91,9 +91,6 @@ struct hashCookie
 bits32 hashString(char *string);
 /* Compute a hash value of a string. */
 
-bits32 hashCrc(char *string);
-/* Returns a CRC value on string. */
-
 struct hashEl *hashLookup(struct hash *hash, char *name);
 /* Looks for name in hash table. Returns associated element,
  * if found, or NULL if not.  If there are multiple entries
@@ -104,12 +101,6 @@ struct hashEl *hashLookupUpperCase(struct hash *hash, char *name);
 /* Lookup upper cased name in hash. (Assumes all elements of hash
  * are themselves already in upper case.) */
 
-struct hashEl *hashLookupNext(struct hashEl *hashEl);
-/* Find the next occurance of name that may occur in the table multiple times,
- * or NULL if not found.  Use hashLookup to find the first occurrence.  Elements
- * are returned in LIFO order.
- */
-
 struct hashEl *hashAdd(struct hash *hash, char *name, void *val);
 /* Add new element to hash table.  If an item with name, already exists, a new
  * item is added in a LIFO manner.  The last item added for a given name is
@@ -137,26 +128,12 @@ struct hashEl *hashAddSaveName(struct hash *hash, char *name, void *val, char **
  *    hashAddSaveName(hash, name, el, &el->name);
  */
 
-struct hashEl *hashStore(struct hash *hash, char *name);
-/* If element in hash already return it, otherwise add it
- * and return it. */
-
-char  *hashStoreName(struct hash *hash, char *name);
-/* Put name into hash table. */
-
-char *hashMustFindName(struct hash *hash, char *name);
-/* Return name as stored in hash table (in hel->name). 
- * Abort if not found. */
-
 void *hashMustFindVal(struct hash *hash, char *name);
 /* Lookup name in hash and return val.  Abort if not found. */
 
 void *hashFindVal(struct hash *hash, char *name);
 /* Look up name in hash and return val or NULL if not found. */
 
-void *hashOptionalVal(struct hash *hash, char *name, void *usual);
-/* Look up name in hash and return val, or usual if not found. */
-
 void *hashFindValUpperCase(struct hash *hash, char *name);
 /* Lookup upper cased name in hash and return val or return NULL if not found.
  * (Assumes all elements of hash are themselves already in upper case.) */
@@ -164,9 +141,6 @@ void *hashFindValUpperCase(struct hash *hash, char *name);
 struct hashEl *hashAddInt(struct hash *hash, char *name, int val);
 /* Store integer value in hash */
 
-void hashIncInt(struct hash *hash, char *name);
-/* Increment integer value in hash */
-
 int hashIntVal(struct hash *hash, char *name);
 /* Return integer value associated with name in a simple 
  * hash of ints. */
@@ -175,12 +149,6 @@ int hashIntValDefault(struct hash *hash, char *name, int defaultInt);
 /* Return integer value associated with name in a simple 
  * hash of ints or defaultInt if not found. */
 
-long long hashIntSum(struct hash *hash);
-/* Return sum of all the ints in a hash of ints. */
-
-void hashTraverseEls(struct hash *hash, void (*func)(struct hashEl *hel));
-/* Apply func to every element of hash with hashEl as parameter. */
-
 void hashTraverseVals(struct hash *hash, void (*func)(void *val));
 /* Apply func to every element of hash with hashEl->val as parameter. */
 
@@ -190,16 +158,6 @@ struct hashEl *hashElListHash(struct hash *hash);
 int hashElCmp(const void *va, const void *vb);
 /* Compare two hashEl by name. */
 
-int hashElCmpWithEmbeddedNumbers(const void *va, const void *vb);
-/* Compare two hashEl by name sorting including numbers within name,
- * suitable for chromosomes, genes, etc. */
-
-void *hashElFindVal(struct hashEl *list, char *name);
-/* Look up name in hashEl list and return val or NULL if not found. */
-
-void hashElFree(struct hashEl **pEl);
-/* Free hash el list returned from hashListAll.  */
-
 void hashElFreeList(struct hashEl **pList);
 /* Free hash el list returned from hashListAll.  (Don't use
  * this internally. */
@@ -213,13 +171,6 @@ struct hashEl* hashNext(struct hashCookie *cookie);
  * hash table while this is being used. (see note in code if you want to fix
  * this) */
 
-void *hashNextVal(struct hashCookie *cookie);
-/* Return the next value in the hash table, or NULL if no more. Do not modify
- * hash table while this is being used. */
-
-char *hashNextName(struct hashCookie *cookie);
-/* Return the next name in the hash table, or NULL if no more. Do not modify
- * hash table while this is being used. */
 
 struct hash *newHashExt(int powerOfTwoSize, boolean useLocalMem);
 /* Returns new hash table. Uses local memory optionally. */
@@ -232,54 +183,13 @@ struct hash *newHashExt(int powerOfTwoSize, boolean useLocalMem);
 void hashResize(struct hash *hash, int powerOfTwoSize);
 /* Resize the hash to a new size */
 
-struct hash *hashFromSlNameList(void *list);
-/* Create a hash out of a list of slNames. */
-
-struct hash *hashSetFromSlNameList(void *list);
-/* Create a hashSet (hash without values) out of a list of slNames. */
-
 void freeHash(struct hash **pHash);
 /* Free up hash table. */
 #define hashFree(a) freeHash(a)	/* Synonym */
 
-void freeHashAndVals(struct hash **pHash);
-/* Free up hash table and all values associated with it.
- * (Just calls freeMem on each hel->val) */
-
-void hashFreeWithVals(struct hash **pHash, void (freeFunc)());
-/* Free up hash table and all values associated with it. freeFunc is a
- * function to free an entry, should take a pointer to a pointer to an
- * entry. */
-
-void hashFreeList(struct hash **pList);
-/* Free up a list of hashes. */
-
-void hashHisto(struct hash *hash, char *fname);
-/* Output bucket usage counts to a file for producing a histogram  */
-
-void hashPrintStats(struct hash *hash, char *label, FILE *fh);
-/* print statistic about a hash table */
-
-struct hashEl *hashReplace(struct hash *hash, char *name, void *val);
-/* Replace an existing element in hash table, or add it if not present. */
-
-boolean hashMayRemove(struct hash *hash, char *name);
-/* Remove item of the given name from hash table, if present.
- * Return true if it was present */
-
-void hashMustRemove(struct hash *hash, char *name);
-/* Remove item of the given name from hash table, or error
- * if not present */
-
-char *hashToRaString(struct hash *hash);
-/* Convert hash to string in ra format. */
 
 int hashNumEntries(struct hash *hash);
 /* count the number of entries in a hash */
 
-struct hash *hashFromString(char *string);
-/* parse a whitespace-separated string with tuples in the format name=val or
- * name="val" to a hash name->val */
-
 #endif /* HASH_H */
 
