@@ -8,18 +8,9 @@
 #ifndef HMMSTATS_H
 #define HMMSTATS_H
 
-int scaledLog(double val);
-/* Return scaled log of val. */
-
 #define logScaleFactor 1000
 /* Amount we scale logs by. */
 
-double simpleGaussean(double x);
-/* Gaussean distribution with standard deviation 1 and mean 0. */
-
-double gaussean(double x, double mean, double sd);
-/* Gaussean distribution with mean and standard deviation at point x  */
-
 double calcVarianceFromSums(double sum, double sumSquares, bits64 n);
 /* Calculate variance. */
 
