@@ -81,11 +81,6 @@ char *udcFileReadAll(char *url, char *cacheDir, size_t maxSize, size_t *retSize)
  * returns size of file in *retSize. Do a freeMem or freez of the returned buffer
  * when done. */
 
-struct lineFile *udcWrapShortLineFile(char *url, char *cacheDir, size_t maxSize);
-/* Read in entire short (up to maxSize) url into memory and wrap a line file around it.
- * The cacheDir may be null in which case udcDefaultDir() will be used.  If maxSize
- * is zero then a default value (currently 64 meg) will be used. */
-
 void udcSeek(struct udcFile *file, bits64 offset);
 /* Seek to a particular (absolute) position in file. */
 
@@ -126,10 +121,6 @@ void udcSetDefaultDir(char *path);
 struct slName *udcFileCacheFiles(char *url, char *cacheDir);
 /* Return low-level list of files used in cache. */
 
-char *udcPathToUrl(const char *path, char *buf, size_t size, char *cacheDir);
-/* Translate path into an URL, store in buf, return pointer to buf if successful
- * and NULL if not. */
-
 long long int udcSizeFromCache(char *url, char *cacheDir);
 /* Look up the file size from the local cache bitmap file, or -1 if there
  * is no cache for url. */
@@ -142,10 +133,6 @@ int udcCacheTimeout();
 /* Get cache timeout (if local cache files are newer than this many seconds,
  * we won't ping the remote server to check the file size and update time). */
 
-void udcSetCacheTimeout(int timeout);
-/* Set cache timeout (if local cache files are newer than this many seconds,
- * we won't ping the remote server to check the file size and update time). */
-
 time_t udcUpdateTime(struct udcFile *udc);
 /* return udc->updateTime */
 
@@ -156,9 +143,6 @@ boolean udcFastReadString(struct udcFile *f, char buf[256]);
 off_t udcFileSize(char *url);
 /* fetch remote or loca file size from given URL or path */
 
-boolean udcExists(char *url);
-/* return true if a remote or local file exists */
-
 boolean udcIsLocal(char *url);
 /* return true if url is not a http or ftp file, just a normal local file path */
 
